module Quandl
module Sandbox

module Attributes
  
  extend ActiveSupport::Concern

  included do
  
    @attributes = []
  
  end
  
  module ClassMethods
  
    def attributes
      @attributes
    end
    
    def define_attributes(*names)
      names.each do |name|
        name = name.to_sym
        next if @attributes.include?(name)
        @attributes << name
        attr_accessor(name)
      end
    end
    
  end
  
  def initialize(*args)
    self.attributes = args.extract_options!
    super if defined?(super)
  end
  
  def attributes
    self.class.attributes.inject({}){|m,name| m.merge({ name.to_sym => self.send(name) }) }
  end
  
  def attributes=(pairs)
    # ensure symbolic keys
    pairs.symbolize_keys!
    # assign each acceptable pair
    self.class.attributes.each do |name|
      self.send("#{name}=", pairs[name] ) if pairs[name]
    end
  end
  
end

end
end