module Quandl::Sandbox
  
  class << self
    attr_accessor :configuration
  end
  
  def self.configuration
    @configuration ||= Configuration.new
  end
  
  def self.configure
    yield(configuration)
    true
  end
  
  class Configuration
  
    include Quandl::Sandbox::Attributes
  
    define_attributes :image, :instance_type, :availability_zone, :ssh_gateway, 
      :ssh_user, :subnet_id, :environment, :verbose, :webhoook, :tmp_dir,
      :aws_access_key_id, :aws_secret_access_key, :key_name, :key_file
    
    def initialize
      @instance_type = 'm1.small'
      @availability_zone = 'us-east-1c'
      @ssh_user = 'ubuntu'
      @environment ||= ( ENV['APP_ENV'] || ENV['RAILS_ENV'] || 'development' )
      @verbose = ( @environment == 'production' ) ? false : true
      @key_name = 'quandl_3'
      @tmp_dir = File.join( Quandl::Sandbox.root, 'tmp/' )
    end
    
    def key_data
      File.read(key_file)
    end
    
    def to_h
      self.attributes
    end
    
  end
  
end