class Quandl::Sandbox::Dataset
  
  attr_accessor :source_code, :code, :name, :description, :data, :column_names
  
  def self.from_output(outputs)
    outputs.split("----\n").collect do |output|
      self.new(output)
    end
  end
  
  def initialize(output)
    rows = output.split("\n")
    self.full_code = rows.shift.strip
    self.name = rows.shift.strip
    self.description = rows.shift.strip
    self.column_names = rows.shift
    self.data = rows.join("\n").strip
  end
  
  def inspect
    "<##{self.class.name}" + 
    [:full_code, :name, :description, :column_names].inject({}){|m,k| m[k] = self.send(k); m }.to_s +
    " >"
  end
  
  def column_names=(names)
    names = names.split(",").collect(&:strip) if names.is_a?(String)
    @column_names = Array(names).flatten
  end
  
  def full_code=(value)
    value = value.split('/')
    self.source_code = value[0]
    self.code = value[1]
  end
  
  def full_code
    [source_code, code].join('/')
  end
  
  def data=(rows)
    @data = Quandl::Data.new(rows)
  end
  
end
