class Quandl::Sandbox::EC2
  
  class << self
    
    def auto_retry(attempt = 3, &block)
      block.call
    rescue => e
      Quandl::Logger.debug("auto_retry #{e} #{attempt}")
      Quandl::Sandbox::EC2.gateway_reset!
      attempt -= 1
      auto_retry(attempt, &block) if attempt > 0
    end
    
    def find(uid)
      instances.filter('instance-id', uid ).collect{ |i| i }.first
    end
    
    def instances
      interface.instances.filter('subnet-id', Quandl::Sandbox.configuration.subnet_id )
    end
    
    def gateway_reset!
      @gateway.shutdown!
      @gateway = nil
    rescue => err
      Quandl::Logger.error("gateway_reset! #{err}")
    end
    
    def gateway
      @gateway ||= Net::SSH::Gateway.new( gateway_host, gateway_user )  
    end
    
    def gateway_user
      @gateway_user ||= Quandl::Sandbox.configuration.ssh_gateway.split("@").first
    end
    
    def gateway_host
      @gateway_host ||= Quandl::Sandbox.configuration.ssh_gateway.split("@").last
    end
    
    def interface
      @interface ||= AWS::EC2.new(
        access_key_id:      Quandl::Sandbox.configuration.aws_access_key_id,
        secret_access_key:  Quandl::Sandbox.configuration.aws_secret_access_key)
    end
  
  end
  
end