class Quandl::Sandbox::Job
  
  attr_accessor :repository, :server, :server_id, :output, :attempts
  
  def initialize(*args)
    options = args.extract_options!.symbolize_keys!
    self.repository = Quandl::Sandbox::Repository.new(options[:repository]) if options[:repository].present?
    self.server = Quandl::Sandbox::Server.find( options[:server_id] ) if options[:server_id].present?
  end
  
  def datasets
    @datasets ||= Quandl::Sandbox::Dataset.from_output( output[:stdout] )
  end
  
  def execute
    # run commands that need to happen before importer
    server.exec( repository.script.before_execute )
    # execute importer
    self.output = server.exec( repository.script.execute )
  rescue => err
    Quandl::Logger.error( err )
  ensure
    server.delete
  end
  
  def output=(value)
    @datasets = nil
    @output = value
  end
  
  def server
    @server ||= Quandl::Sandbox::Server.create
  end
  
end