class Quandl::Sandbox::Repository
  
  include Quandl::Sandbox::Attributes
  
  define_attributes :job_uid, :git, :ref
  
  def git=(value)
    @full_path = nil
    @git = URI.escape( value.to_s )
  end
  
  def ref=(value)
    @ref = URI.escape( value.to_s )
  end
  
  def full_path
    @full_path ||= File.join( '/home/ubuntu', dirname )
  end
  
  def dirname
    @dirname ||= git.to_s.parameterize
  end
  
  def script
    @script ||= Script.new(self)
  end
  
  class Script
    
    attr_accessor :repository
    
    def initialize(repo)
      self.repository = repo
    end
    
    def before_execute
      [ clone, checkout, pull, bundle ].join("\n")
    end
    
    def execute
      "cd #{r.full_path}; bundle exec ruby import.rb"
    end
    
    def clone
      %Q{git clone "#{r.git}" "#{r.full_path}"}
    end
  
    def checkout
      %Q{ cd #{r.full_path}
      git checkout -b "#{r.ref}"}
    end
  
    def pull
      %Q{ cd #{r.full_path}; git pull origin "#{r.ref}" }
    end
    
    def bundle
      "cd #{r.full_path}; bundle update"
    end
    
    def r
      repository
    end
    
  end
  
end