module Quandl
module Sandbox

class Server
module Attributes
  
  extend ActiveSupport::Concern
  
  included do
    include Quandl::Sandbox::Attributes
    
    define_attributes :image, :instance_type, :availability_zone,
      :ssh_gateway, :ssh_user, :subnet_id, :environment, :node_name,
      :key_name
    
    attr_reader :new_record
    
    def node_name
      @node_name ||= "#{environment}-sandbox-worker-#{uid}"
    end
    
  end
  
  def initialize(*args)
    # is a new record
    self.new_record = true
    # default attributes
    self.attributes = Quandl::Sandbox.configuration.to_h
    # onwards
    super
  end
  
  def uid
    @uid ||= SecureRandom.hex(6)
  end
  
  def tags
    {
      Name:                   node_name,
      cluster_type:           'quandl_sandbox',
      instance_type:          'quandl_ugc_worker',
      instance_environment:   environment,
      vpc:                    ssh_gateway.present? ? 'true' : 'false'
    }
  end
  
  private
  
  def new_record=(value)
    @new_record = (value == true)
  end
  
end
end

end
end