module Quandl::Sandbox::Server::Instance

  extend ActiveSupport::Concern

  included do
  
    TIMEOUT = 60
  
    delegate :status, :delete, :exists?, :subnet,
    to: :instance, allow_nil: true

    attr_reader :instance

  end

  module ClassMethods
    
    def find_or_create(uid)
      find(uid) || create
    end

    def find(uid)
      # lookup instance
      instance = Quandl::Sandbox::EC2.find(uid)
      # build server given instance
      instance.present? ? self.new( instance: instance ) : nil
    end

    def create(*args)
      s = self.new(*args)
      s.launch!
      s
    end
    
    def delete(id)
      i = Quandl::Sandbox::EC2.find(id)
      i.present? ? i.delete : false
    end

  end
  
  def initialize(*args)
    # grab instance if present
    instance = args.try(:last).try(:[], :instance)
    # upwards
    super
    # assign instance if given
    self.instance = instance if instance.present?
  end
  
  def private_ip_address
    @private_ip_address ||= instance.try(:private_ip_address)
  end

  def instance_id
    @instance_id ||= instance.try(:id)
  end

  def running?
    @running ||= (status == :running) ? true : nil
  end

  def launch!
    self.instance = create_instance!
    add_tags_to_instance
  end

  def await_instance_uninterruptedly
    t1 = Time.now
    Quandl::Logger.debug "#{instance_id}: Waiting for instance to start up ... "
    Timeout::timeout(TIMEOUT) {
      sleep 0.5 while status == :pending
    }
    Quandl::Logger.debug "#{instance_id}: Instance started. (#{t1.elapsed_ms})"
    true
  end


  private


  def instance=(instance)
    raise( ArgumentError, "instance must be of class AWS::EC2::Instance") unless instance.kind_of?(AWS::EC2::Instance)
    return false unless new_record
    # assign instance
    @instance = instance
    assign_attributes_using_instance
    self.new_record = false
  end

  def create_instance!
    Quandl::Sandbox::EC2.instances.create({
      image_id:             image,
      subnet_id:            subnet_id,
      availability_zone:    availability_zone,
      key_name:             key_name,
      instance_type:        instance_type 
    })
  end

  def assign_attributes_using_instance
    self.class.attributes.each do |name|
      self.send("#{name}=", instance.send(name)) if instance.respond_to?(name)
    end
    @node_name = instance.tags['Name']
    @uid = @node_name.to_s.split('-').last
  end

  def add_tags_to_instance
    tags.each{|key, value| instance.add_tag( key.to_s, value: value.to_s ) }
  end

end